Struct CaptureOptions

pub struct CaptureOptions(/* private fields */);
Available on crate feature wayland and Linux only.

Implementations



impl Options

pub const PaintCursors: Options

paint cursors onto captured frames



impl Options

pub const fn empty() -> Options

Get a flags value with all bits unset.

pub const fn all() -> Options

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Options>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Options

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Options

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Options>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Options) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Options) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Options)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Options)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Options)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Options, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Options) -> Options

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Options) -> Options

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Options) -> Options

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Options) -> Options

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Options

The bitwise negation (!) of the bits in self, truncating the result.



impl Options

pub const fn iter(&self) -> Iter<Options>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Options>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.